summaryrefslogtreecommitdiffstats
path: root/kbabel/commonui/kactionselector.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/commonui/kactionselector.cpp')
-rw-r--r--kbabel/commonui/kactionselector.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kbabel/commonui/kactionselector.cpp b/kbabel/commonui/kactionselector.cpp
index 699dcc26..52a60bbf 100644
--- a/kbabel/commonui/kactionselector.cpp
+++ b/kbabel/commonui/kactionselector.cpp
@@ -17,11 +17,11 @@
* *
* In addition, as a special exception, the copyright holders give *
* permission to link the code of this program with any edition of *
- * the Qt library by Trolltech AS, Norway (or with modified versions *
- * of Qt that use the same license as Qt), and distribute linked *
+ * the TQt library by Trolltech AS, Norway (or with modified versions *
+ * of TQt that use the same license as TQt), and distribute linked *
* combinations including the two. You must obey the GNU General *
* Public License in all respects for all of the code used other than *
* Qt. If you modify this file, you may extend this exception to *
* your version of the file, but you are not obligated to do so. If *
* you do not wish to do so, delete this exception statement from *
* your version. *
@@ -57,8 +57,8 @@ class KActionSelectorPrivate {
//BEGIN Constructor/destructor
-KActionSelector::KActionSelector( TQWidget *parent, const char *name )
- : TQWidget( parent, name )
+KActionSelector::KActionSelector( TQWidget *tqparent, const char *name )
+ : TQWidget( tqparent, name )
{
d = new KActionSelectorPrivate();
d->moveOnDoubleClick = true;
@@ -360,7 +360,7 @@ void KActionSelector::polish()
void KActionSelector::keyPressEvent( TQKeyEvent *e )
{
if ( ! d->keyboardEnabled ) return;
- if ( (e->state() & Qt::ControlButton) )
+ if ( (e->state() & TQt::ControlButton) )
{
switch ( e->key() )
{
@@ -387,7 +387,7 @@ bool KActionSelector::eventFilter( TQObject *o, TQEvent *e )
{
if ( d->keyboardEnabled && e->type() == TQEvent::KeyPress )
{
- if ( (((TQKeyEvent*)e)->state() & Qt::ControlButton) )
+ if ( (((TQKeyEvent*)e)->state() & TQt::ControlButton) )
{
switch ( ((TQKeyEvent*)e)->key() )
{
@@ -17,11 +17,11 @@
* combinations including the two. You must obey the GNU General *
* Public License in all respects for all of the code used other than *
- * Qt. If you modify this file, you may extend this exception to *
+ * TQt. If you modify this file, you may extend this exception to *
* your version of the file, but you are not obligated to do so. If *
* you do not wish to do so, delete this exception statement from *